//
//  ViewController.swift
//  SwiftCompass
//
//  Created by Hey Eleven on 16/5/12.
//  Copyright © 2016年 Eleven Yao. All rights reserved.
//

import UIKit
import CoreLocation
import CoreMotion

class ViewController: UIViewController, CLLocationManagerDelegate {

    var _lm:CLLocationManager!
    
    var _cmm:CMMotionManager!
    
    var _stepCounter:CMPedometer!
    
    var _queue:NSOperationQueue!
    
    var _compassImageView:UIImageView!
    
    var _stepCountLabel:UILabel!
    
    var _date:NSDate!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        _queue = NSOperationQueue()
        
        _date = NSDate()
        
        _lm = CLLocationManager()
        _lm.delegate = self
        
        _cmm = CMMotionManager()
        
        _stepCounter = CMPedometer()
        
        _compassImageView = UIImageView()
        _compassImageView.image = UIImage.init(named: "compass")
        _compassImageView.frame = CGRectMake(self.view.frame.size.width/2 - 40, self.view.frame.size.height/2 - 150, 80, 300)
        self.view.addSubview(_compassImageView)
        
        _stepCountLabel = UILabel.init(frame: CGRectMake(20, self.view.frame.size.height - 50, self.view.frame.size.width - 40, 50))
        _stepCountLabel.text = "开始统计行走步数"
        self.view.addSubview(_stepCountLabel)
    }
    
    override func viewWillAppear(animated: Bool) {
        
        _lm.startUpdatingHeading()
        
//        startMagnetometerUpdate()
//        
//        startGyroUpdate()
//        
//        startListenLevel()
        
        startPedometerUpdate()
        
//        startAccelerometerUpdate()
//        
//        startListenProximity()
    }
    
    override func viewWillDisappear(animated: Bool) {
        
//        stopGyroUpdate()
//        
//        stopListenLevel()
//
//        stopListenProximity()
//        
//        stopMagnetometerUpdate()
//        
//        stopAccelerometerUpdate()
        
    }
    
    //  方位服务 指南针
    func locationManager(manager: CLLocationManager, didUpdateHeading newHeading: CLHeading) {
        
        _compassImageView.transform = CGAffineTransformMakeRotation(CGFloat(-newHeading.magneticHeading/180 * M_PI))
    }
    
    //  磁强仪
    func startMagnetometerUpdate() {
        
        _cmm.magnetometerUpdateInterval = 1
        
        if _cmm.magnetometerAvailable && !_cmm.magnetometerActive {
            
            _cmm.startMagnetometerUpdatesToQueue(_queue, withHandler: { (magnetometerData:CMMagnetometerData?, error:NSError?) in
                
                print("magnetometer Data : \(magnetometerData)")
            })
        }else {
            print("磁强仪不可使用")
        }
    }
    
    func stopMagnetometerUpdate() {
        
        if _cmm.magnetometerActive {
            
            _cmm.stopMagnetometerUpdates()
        }
    }
    
    //  加速度传感器
    func startAccelerometerUpdate() {
        
        _cmm.accelerometerUpdateInterval = 1
        
        if _cmm.accelerometerAvailable && !_cmm.accelerometerActive {
            
            _cmm.startAccelerometerUpdatesToQueue(_queue, withHandler: { (accelerometerData:CMAccelerometerData?, error: NSError?) in
                
                print("accelerometer Data : \(accelerometerData)")
            })
        }else {
            print("加速度传感器不可用")
        }
    }
    
    func stopAccelerometerUpdate() {
        
        if _cmm.accelerometerActive {
            
            _cmm.stopAccelerometerUpdates()
        }
    }
    
    //  陀螺仪
    func startGyroUpdate() {
        
        _cmm.gyroUpdateInterval = 1
        
        if _cmm.gyroAvailable && !_cmm.gyroActive {
            
            _cmm.startGyroUpdatesToQueue(_queue, withHandler: { (gyroData: CMGyroData?, error: NSError?) in
                
                print("gyro Data : \(gyroData)")
            })
        }else {
            print("陀螺仪不可用")
        }
    }
    
    func stopGyroUpdate() {
        
        if _cmm.gyroActive {
            
            _cmm.stopGyroUpdates()
        }
    }
    
    //  计步器
    func startPedometerUpdate() {
        
        if CMPedometer.isStepCountingAvailable() {
            
            _stepCounter.startPedometerUpdatesFromDate(_date, withHandler: { (pedometerData: CMPedometerData?, erroe: NSError?) in
                
                self._stepCountLabel.text = "当前行走步数 : \(pedometerData!.numberOfSteps)"
                print("当前行走步数 : \(pedometerData!.numberOfSteps)")
            })
        }else {
            print("计步器不可使用")
        }
    }
    
    //  距离传感器
    func startListenProximity() {
        
        UIDevice.currentDevice().proximityMonitoringEnabled = true
        
        NSNotificationCenter.defaultCenter().addObserver(self, selector: #selector(ViewController.proximityChanged), name: UIDeviceProximityStateDidChangeNotification, object: nil)
    }
    
    func stopListenProximity() {
        
        NSNotificationCenter.defaultCenter().removeObserver(self, name: UIDeviceProximityStateDidChangeNotification, object: nil)
    }
    
    func proximityChanged() {
        
        if UIDevice.currentDevice().proximityState {
            print("前方出现不明物体")
        }else {
            print("一无所有")
        }
    }
    
    //  设备电量
    func startListenLevel() {
        
        UIDevice.currentDevice().batteryMonitoringEnabled = true
        
        print("设备电量 : \(UIDevice.currentDevice().batteryLevel * 100)%")
        
        NSNotificationCenter.defaultCenter().addObserver(self, selector: #selector(ViewController.levelChanged), name: UIDeviceBatteryLevelDidChangeNotification, object: nil)
    }
    
    func stopListenLevel() {
        
        NSNotificationCenter.defaultCenter().removeObserver(self, name: UIDeviceBatteryLevelDidChangeNotification, object: nil)
    }
    
    func levelChanged() {
        
        if UIDevice.currentDevice().batteryLevel < 0.2 {
            
            //  当设备电量少于20%时禁止某些操作
        }
        
        print("设备电量 : \(UIDevice.currentDevice().batteryLevel * 100)%")
    }


}

